==> eiffelstudio-18.07.10.1981.tar: F_code/C6/et251.c <==
/*
 * Code for class ET_FLATTENING_STATUS_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "et251.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ET_FLATTENING_STATUS_CHECKER}.make */
void F796_6109 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	F793_6089(Current);
	tr1 = RTLNSMART(eif_new_type(144, 0).id);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {ET_FLATTENING_STATUS_CHECKER}.process_class */
void F796_6110 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTGC;
	tb1 = F1625_15918(RTCW(arg1));
	if (tb1) {
		F1625_16096(RTCW(arg1));
	} else {
		tr1 = *(EIF_REFERENCE *)(Current);
		tb1 = F1625_15935(RTCW(tr1));
		if ((EIF_BOOLEAN) !tb1) {
			F1618_15687(RTCV(F793_6094(Current)));
			tr1 = RTLNSMART(Dftype(Current));
			F796_6109(RTCW(tr1));
			loc1 = (EIF_REFERENCE) tr1;
			F796_6110(RTCW(loc1), arg1);
		} else {
			tb1 = F1625_15935(RTCW(arg1));
			if (tb1) {
				F796_6111(Current, arg1);
				F1618_15687(RTCV(F793_6094(Current)));
			} else {
				tb1 = F1625_15976(RTCW(arg1));
				if ((EIF_BOOLEAN) !tb1) {
					F796_6111(Current, arg1);
				} else {
					F796_6112(Current, arg1);
				}
			}
		}
	}
	RTLE;
}

/* {ET_FLATTENING_STATUS_CHECKER}.set_fatal_error */
void F796_6111 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F1625_15911(RTCW(arg1));
}

/* {ET_FLATTENING_STATUS_CHECKER}.internal_process_class */
void F796_6112 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc7 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,arg1);
	RTLR(3,tr1);
	RTLR(4,loc6);
	RTLR(5,loc8);
	RTLIU(6);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current);
	tb2 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_27_12_);
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tb2 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_27_11_);
		tb1 = tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current);
		F1625_16096(RTCW(tr1));
		tr1 = *(EIF_REFERENCE *)(Current);
		loc3 = F1625_16043(RTCW(tr1));
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN) (loc2 > loc3)) break;
			tr1 = *(EIF_REFERENCE *)(Current);
			loc6 = F1625_16044(RTCW(tr1), loc2);
			loc5 = *(EIF_INTEGER_32 *)(RTCW(loc6)+ _LNGOFF_3_0_0_0_);
			loc4 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			for (;;) {
				if ((EIF_BOOLEAN) (loc4 > loc5)) break;
				loc8 = F1287_12247(RTCW(loc6), loc4);
				loc8 = *(EIF_REFERENCE *)(RTCW(loc8));
				loc8 = F1622_15784(RTCW(loc8));
				tb1 = F1625_15976(RTCW(loc8));
				if (tb1) {
					F796_6112(Current, loc8);
					tb1 = *(EIF_BOOLEAN *)(RTCW(loc8)+ _CHROFF_27_12_);
					if ((EIF_BOOLEAN) !tb1) {
						loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
					}
				} else {
					loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				}
				loc4++;
			}
			loc2++;
		}
		if (loc7) {
			F796_6111(Current, *(EIF_REFERENCE *)(Current));
		} else {
			tr1 = *(EIF_REFERENCE *)(Current);
			tb1 = F1625_16001(RTCW(tr1));
			if ((EIF_BOOLEAN) !tb1) {
				F796_6113(Current);
				F796_6114(Current);
			}
			F796_6115(Current);
		}
	}
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
	RTLE;
}

/* {ET_FLATTENING_STATUS_CHECKER}.check_formal_parameters_validity */
void F796_6113 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc3);
	RTLR(3,loc4);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_27_12_);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_3_);
		loc3 = tr1;
		if (EIF_TEST(loc3)) {
			loc2 = *(EIF_INTEGER_32 *)(loc3+ _LNGOFF_3_0_0_0_);
			loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			for (;;) {
				if ((EIF_BOOLEAN) (loc1 > loc2)) break;
				tr1 = F1520_13906(loc3, loc1);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10162[Dtype(tr1)-1500])(RTCW(tr1));
				loc4 = tr1;
				if (EIF_TEST(loc4)) {
					tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
					F145_1617(RTCW(tr1), loc4);
					tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
					tb1 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_0_0_);
					if (tb1) {
						F796_6111(Current, *(EIF_REFERENCE *)(Current));
						loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L));
					}
				}
				loc1++;
			}
		}
	}
	RTLE;
}

/* {ET_FLATTENING_STATUS_CHECKER}.check_parents_validity */
void F796_6114 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc5);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_27_12_);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current);
		loc2 = F1625_16043(RTCW(tr1));
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN) (loc1 > loc2)) break;
			tr1 = *(EIF_REFERENCE *)(Current);
			loc5 = F1625_16044(RTCW(tr1), loc1);
			loc4 = *(EIF_INTEGER_32 *)(RTCW(loc5)+ _LNGOFF_3_0_0_0_);
			loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			for (;;) {
				if ((EIF_BOOLEAN) (loc3 > loc4)) break;
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
				tr2 = F1287_12247(RTCW(loc5), loc3);
				tr2 = *(EIF_REFERENCE *)(RTCW(tr2));
				F145_1617(RTCW(tr1), tr2);
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
				tb1 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_0_0_);
				if (tb1) {
					F796_6111(Current, *(EIF_REFERENCE *)(Current));
					loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 + ((EIF_INTEGER_32) 1L));
					loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L));
				}
				loc3++;
			}
			loc1++;
		}
	}
	RTLE;
}

/* {ET_FLATTENING_STATUS_CHECKER}.check_signatures_validity */
void F796_6115 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_27_12_);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_23_);
		F796_6116(Current, tr1);
	}
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_27_12_);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_22_);
		F796_6116(Current, tr1);
	}
	RTLE;
}

/* {ET_FLATTENING_STATUS_CHECKER}.check_feature_signatures_validity */
void F796_6116 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc6 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc8 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(7);
	RTLR(0,arg1);
	RTLR(1,loc7);
	RTLR(2,loc1);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc9);
	RTLR(6,loc2);
	RTLIU(7);
	
	RTGC;
	loc4 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_0_0_1_);
	loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc3 > loc4)) break;
		loc7 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R5703[Dtype(arg1)-844])(RTCW(arg1), loc3);
		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R8093[Dtype(loc7)-1459])(RTCW(loc7));
		if ((EIF_BOOLEAN)(loc1 != NULL)) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			F145_1617(RTCW(tr1), loc1);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tb1 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_0_0_);
			if (tb1) {
				F796_6111(Current, *(EIF_REFERENCE *)(Current));
				loc8 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 + ((EIF_INTEGER_32) 1L));
			}
		}
		if ((EIF_BOOLEAN) !loc8) {
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R8094[Dtype(loc7)-1459])(RTCW(loc7));
			loc9 = tr1;
			if (EIF_TEST(loc9)) {
				loc2 = (EIF_REFERENCE) NULL;
				loc6 = *(EIF_INTEGER_32 *)(loc9+ _LNGOFF_3_0_0_0_);
				loc5 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
				for (;;) {
					if ((EIF_BOOLEAN) (loc5 > loc6)) break;
					loc1 = F1273_12112(loc9, loc5);
					loc1 = F1441_13024(RTCW(loc1));
					if ((EIF_BOOLEAN)(loc1 != loc2)) {
						tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
						F145_1617(RTCW(tr1), loc1);
						tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
						tb1 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_0_0_);
						if (tb1) {
							F796_6111(Current, *(EIF_REFERENCE *)(Current));
							loc5 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc6 + ((EIF_INTEGER_32) 1L));
							loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 + ((EIF_INTEGER_32) 1L));
						}
						loc2 = (EIF_REFERENCE) loc1;
					}
					loc5++;
				}
			}
		}
		loc3++;
	}
	RTLE;
}

/* {ET_FLATTENING_STATUS_CHECKER}.class_type_checker */
EIF_REFERENCE F796_6117 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit251 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C6/et251.c <==
/*
 * Code for class ET_ANCESTORS_STATUS_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "et251.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ET_ANCESTORS_STATUS_CHECKER}.make */
void F797_6140 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	F795_6125(Current);
	tr1 = RTLNSMART(eif_new_type(144, 0).id);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {ET_ANCESTORS_STATUS_CHECKER}.process_class */
void F797_6141 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTGC;
	tb1 = F1627_15958(RTCW(arg1));
	if (tb1) {
		F1627_16090(RTCW(arg1));
	} else {
		tr1 = *(EIF_REFERENCE *)(Current);
		tb1 = F1627_15975(RTCW(tr1));
		if ((EIF_BOOLEAN) !tb1) {
			F1620_15727(RTCV(F795_6130(Current)));
			tr1 = RTLNSMART(Dftype(Current));
			F797_6140(RTCW(tr1));
			loc1 = (EIF_REFERENCE) tr1;
			F797_6141(RTCW(loc1), arg1);
		} else {
			tb1 = F1627_15975(RTCW(arg1));
			if (tb1) {
				F797_6142(Current, arg1);
				F1620_15727(RTCV(F795_6130(Current)));
			} else {
				tb1 = F1627_16016(RTCW(arg1));
				if ((EIF_BOOLEAN) !tb1) {
					F797_6142(Current, arg1);
				} else {
					F797_6143(Current, arg1);
				}
			}
		}
	}
	RTLE;
}

/* {ET_ANCESTORS_STATUS_CHECKER}.set_fatal_error */
void F797_6142 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F1627_15950(RTCW(arg1));
}

/* {ET_ANCESTORS_STATUS_CHECKER}.internal_process_class */
void F797_6143 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc7 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,arg1);
	RTLR(3,tr1);
	RTLR(4,loc6);
	RTLR(5,loc8);
	RTLIU(6);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current);
	tb2 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_27_14_);
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tb2 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_27_13_);
		tb1 = tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current);
		F1627_16090(RTCW(tr1));
		tr1 = *(EIF_REFERENCE *)(Current);
		loc3 = F1627_16083(RTCW(tr1));
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN) (loc2 > loc3)) break;
			tr1 = *(EIF_REFERENCE *)(Current);
			loc6 = F1627_16084(RTCW(tr1), loc2);
			loc5 = *(EIF_INTEGER_32 *)(RTCW(loc6)+ _LNGOFF_3_0_0_0_);
			loc4 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			for (;;) {
				if ((EIF_BOOLEAN) (loc4 > loc5)) break;
				loc8 = F1289_12292(RTCW(loc6), loc4);
				loc8 = *(EIF_REFERENCE *)(RTCW(loc8));
				loc8 = F1624_15824(RTCW(loc8));
				tb1 = F1627_16016(RTCW(loc8));
				if (tb1) {
					F797_6143(Current, loc8);
					tb1 = *(EIF_BOOLEAN *)(RTCW(loc8)+ _CHROFF_27_14_);
					if ((EIF_BOOLEAN) !tb1) {
						loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
					}
				} else {
					loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				}
				loc4++;
			}
			loc2++;
		}
		if (loc7) {
			F797_6142(Current, *(EIF_REFERENCE *)(Current));
		} else {
			tr1 = *(EIF_REFERENCE *)(Current);
			tb1 = F1627_16041(RTCW(tr1));
			if ((EIF_BOOLEAN) !tb1) {
				F797_6144(Current);
				F797_6145(Current);
			}
		}
	}
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
	RTLE;
}

/* {ET_ANCESTORS_STATUS_CHECKER}.check_formal_parameters_validity */
void F797_6144 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc3);
	RTLR(3,loc4);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_27_14_);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_3_);
		loc3 = tr1;
		if (EIF_TEST(loc3)) {
			loc2 = *(EIF_INTEGER_32 *)(loc3+ _LNGOFF_3_0_0_0_);
			loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			for (;;) {
				if ((EIF_BOOLEAN) (loc1 > loc2)) break;
				tr1 = F1518_13891(loc3, loc1);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10192[Dtype(tr1)-1502])(RTCW(tr1));
				loc4 = tr1;
				if (EIF_TEST(loc4)) {
					tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
					F145_1635(RTCW(tr1), loc4);
					tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
					tb1 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_0_0_);
					if (tb1) {
						F797_6142(Current, *(EIF_REFERENCE *)(Current));
						loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L));
					}
				}
				loc1++;
			}
		}
	}
	RTLE;
}

/* {ET_ANCESTORS_STATUS_CHECKER}.check_parents_validity */
void F797_6145 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc5);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_27_14_);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current);
		loc2 = F1627_16083(RTCW(tr1));
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN) (loc1 > loc2)) break;
			tr1 = *(EIF_REFERENCE *)(Current);
			loc5 = F1627_16084(RTCW(tr1), loc1);
			loc4 = *(EIF_INTEGER_32 *)(RTCW(loc5)+ _LNGOFF_3_0_0_0_);
			loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			for (;;) {
				if ((EIF_BOOLEAN) (loc3 > loc4)) break;
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
				tr2 = F1289_12292(RTCW(loc5), loc3);
				tr2 = *(EIF_REFERENCE *)(RTCW(tr2));
				F145_1635(RTCW(tr1), tr2);
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
				tb1 = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_0_0_);
				if (tb1) {
					F797_6142(Current, *(EIF_REFERENCE *)(Current));
					loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 + ((EIF_INTEGER_32) 1L));
					loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L));
				}
				loc3++;
			}
			loc1++;
		}
	}
	RTLE;
}

/* {ET_ANCESTORS_STATUS_CHECKER}.class_type_checker */
EIF_REFERENCE F797_6146 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit251 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
